Authors
=======

`German Gomez-Herrero <german@findhotel.net>`_
    original idea and implementation

These people have contributed to ``s3keyring``, in alphabetical order:

* `Ilya Kalinin <https://github.com/ikalinin>`_
